@@ -65,6 +65,11 @@
 ##' \item{\code{\link{plot}}}{diagnostic plots}
 ##' }
 ##'
+##' @section Change in default tolerance:
+##' From \pkg{pomp} version 2.4.1, warnings have been issued whenever the value of \code{tol} is set to anything other than zero.
+##' As of version 2.7.1, the default value of \code{tol} is zero and warnings will be generated whenever it is set by the user to anything else.
+##' This behavior is in anticipation of a forthcoming release, which will remove the \code{tol} and \code{max.fail} arguments altogether.
+##' 
 ##' @section Filtering failures:
 ##' If the degree of disagreement between model and data becomes sufficiently large, a \dQuote{filtering failure} results.
 ##' A filtering failure occurs when, at some time point, none of the \code{Np} particles is compatible with the data.
@@ -95,7 +100,6 @@ setClass(
     saved.states="list",
     Np="integer",
     tol="numeric",
-    nfail="integer",
     loglik="numeric"
   ),
   prototype=prototype(
@@ -110,7 +114,6 @@ setClass(
     saved.states=list(),
     Np=as.integer(NA),
     tol=as.double(NA),
-    nfail=as.integer(NA),
     loglik=as.double(NA)
   )
 )
@@ -146,7 +149,7 @@ setMethod(
   signature=signature(data="data.frame"),
   definition=function (
     data,
-    Np, tol = 1e-17, max.fail = Inf,
+    Np, tol = 0, max.fail = Inf,
     params, rinit, rprocess, dmeasure,
     pred.mean = FALSE,
     pred.var = FALSE,
@@ -189,7 +192,7 @@ setMethod(
   signature=signature(data="pomp"),
   definition=function (
     data,
-    Np, tol = 1e-17, max.fail = Inf,
+    Np, tol = 0, max.fail = Inf,
     pred.mean = FALSE,
     pred.var = FALSE,
     filter.mean = FALSE,
@@ -292,8 +295,8 @@ pfilter.internal <- function (object, Np, tol, max.fail,
     pWarn(
       "pfilter",
       "the ",sQuote("tol")," argument is deprecated and will be removed in a future release.\n",
-      "Currently, the default value of ",sQuote("tol")," is 1e-17;\n",
-      "in future releases, the value will be 0, and the option to choose otherwise will be removed."
+      "Currently, the default value of ",sQuote("tol")," is 0;\n",
+      "in future releases, the option to choose otherwise will be removed."
     )
   }
 
@@ -447,7 +450,6 @@ pfilter.internal <- function (object, Np, tol, max.fail,
     saved.states=xparticles,
     Np=as.integer(Np),
     tol=tol,
-    nfail=as.integer(nfail),
     loglik=sum(loglik)
   )
 }
